ApiResultErrorNetwork<T> class

Inheritance
Available extensions

Constructors

ApiResultErrorNetwork(int? statusCode, String? message)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
response() → T

Available on ApiResult<T>, provided by the ApiResultExtension extension

toApiEither() → Either<Failure, T>

Available on ApiResult<T>, provided by the ApiResultExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited