NetResponse<S> class

Constructors

NetResponse({required int? statusCode, required String? statusMessage, required dynamic body})
NetResponse.fromDio(Response response)
factory
NetResponse.fromHttp(Response response)
factory

Properties

body → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final
statusMessage → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited